# Using the Launchable CLI

First, follow the steps in the [getting-started](getting-started/ "mention") to set your API key, install the Launchable CLI, and verify your connection.

Then complete the two steps for sending your test suite's data to your Launchable workspace:

1. [recording-builds-with-the-launchable-cli](recording-builds-with-the-launchable-cli/ "mention")
2. [recording-test-results-with-the-launchable-cli](recording-test-results-with-the-launchable-cli/ "mention")
